import { HttpService } from '@nestjs/axios';
import {
  Controller,
  Get,
  HttpException,
  HttpStatus,
  Query,
  Redirect,
} from '@nestjs/common';
import { ApiQuery } from '@nestjs/swagger';
import { ConfigService } from '@nestjs/config';
import { JwtService } from '@nestjs/jwt';
import { catchError, lastValueFrom, map } from 'rxjs';
import { AuthService } from './auth.service';

@Controller('auth')
export class AuthController {
  constructor(
    private config: ConfigService,
    private authService: AuthService,
  ) {}

  @Get('/vatsim')
  @ApiQuery({
    name: 'code',
    description: 'The authorization code',
    type: String,
  })
  @Redirect()
  async vatsim(@Query('code') code) {
    if (!code) {
      throw new HttpException(
        'Code not found in the query',
        HttpStatus.NOT_ACCEPTABLE,
      );
    }

    const token = await this.authService.login(code);

    if (token !== undefined) {
      return {
        url: `${this.config.get<string>(
          'frontend.base-url',
        )}/${this.config.get<string>(
          'frontend.login-endpoint',
        )}?token=${token}`,
      };
    } else {
      return {
        url: `${this.config.get<string>(
          'frontend.base-url',
        )}/${this.config.get<string>('frontend.login-endpoint')}`,
      };
    }
  }
}
